@@ -24,7 +24,7 @@ class TestCatalog(NereidTestCase):
     Test Catalog
     """
 
-    def _create_product_category(self, name, **values):
+    def _create_product_category(self, name, vlist):
         """
         Creates a product category
 
@@ -32,148 +32,184 @@ class TestCatalog(NereidTestCase):
         arguments
 
         :param name: Name of the product category
+        :param vlist: List of dictionaries of values to create
         """
-        category_obj = POOL.get('product.category')
+        Category = POOL.get('product.category')
 
-        values['name'] = name
-        return category_obj.create(values)
+        for values in vlist:
+            values['name'] = name
+        return Category.create(vlist)
 
-    def _create_product(self, name, uom=u'Unit', **values):
+    def _create_product_template(
+        self, name, vlist, uri, uom=u'Unit', displayed_on_eshop=True
+    ):
         """
-        Create a product and return its ID
-
-        Additional arguments may be provided as keyword arguments
+        Create a product template with products and return its ID
 
         :param name: Name of the product
+        :param vlist: List of dictionaries of values to create
+        :param uri: uri of product template
         :param uom: Note it is the name of UOM (not symbol or code)
+        :param displayed_on_eshop: Boolean field to display product
+                                   on shop or not
         """
-        product_obj = POOL.get('product.product')
-        uom_obj = POOL.get('product.uom')
+        ProductTemplate = POOL.get('product.template')
+        Uom = POOL.get('product.uom')
 
-        values['name'] = name
-        values['default_uom'], = uom_obj.search([('name', '=', uom)], limit=1)
+        for values in vlist:
+            values['name'] = name
+            values['default_uom'], = Uom.search([('name', '=', uom)], limit=1)
+            values['products'] = [
+                ('create', [{
+                    'uri': uri,
+                    'displayed_on_eshop': displayed_on_eshop,
+                }])
+            ]
 
-        return product_obj.create(values)
+        return ProductTemplate.create(vlist)
 
     def setup_defaults(self):
         """
         Setup the defaults
         """
-        usd = self.currency_obj.create({
+        usd, = self.Currency.create([{
             'name': 'US Dollar',
             'code': 'USD',
             'symbol': '$',
-        })
-        company_id = self.company_obj.create({
+        }])
+        party1, = self.Party.create([{
             'name': 'Openlabs',
-            'currency': usd
-        })
-        guest_user = self.nereid_user_obj.create({
+        }])
+        company, = self.Company.create([{
+            'party': party1.id,
+            'currency': usd.id
+        }])
+        party2, = self.Party.create([{
             'name': 'Guest User',
+        }])
+        guest_user, = self.NereidUser.create([{
+            'party': party2.id,
             'display_name': 'Guest User',
             'email': 'guest@openlabs.co.in',
             'password': 'password',
-            'company': company_id,
-        })
-        self.registered_user_id = self.nereid_user_obj.create({
+            'company': company.id,
+        }])
+        party3, = self.Party.create([{
             'name': 'Registered User',
+        }])
+        self.registered_user, = self.NereidUser.create([{
+            'party': party3.id,
             'display_name': 'Registered User',
             'email': 'email@example.com',
             'password': 'password',
-            'company': company_id,
-        })
+            'company': company.id,
+        }])
 
         # Create product categories
-        category = self._create_product_category(
-            'Category', uri='category'
+        category, = self._create_product_category(
+            'Category', [{'uri': 'category'}]
         )
-        category2 = self._create_product_category(
-            'Category 2', uri='category2'
+        category2, = self._create_product_category(
+            'Category 2', [{'uri': 'category2'}]
         )
-        category3 = self._create_product_category(
-            'Category 3', uri='category3'
+        category3, = self._create_product_category(
+            'Category 3', [{'uri': 'category3'}]
         )
 
         # Create website
-        url_map_id, = self.url_map_obj.search([], limit=1)
-        en_us, = self.language_obj.search([('code', '=', 'en_US')])
-        self.nereid_website_obj.create({
+        url_map, = self.UrlMap.search([], limit=1)
+        en_us, = self.Language.search([('code', '=', 'en_US')])
+        self.NereidWebsite.create([{
             'name': 'localhost',
-            'url_map': url_map_id,
-            'company': company_id,
+            'url_map': url_map.id,
+            'company': company.id,
             'application_user': USER,
-            'default_language': en_us,
+            'default_language': en_us.id,
             'guest_user': guest_user,
-            'categories': [('set', [category, category2])],
-            'currencies': [('set', [usd])],
-        })
+            'categories': [('set', [category.id, category2.id])],
+            'currencies': [('set', [usd.id])],
+        }])
 
-        # Create Sample products
-        self._create_product(
+        # Create product templates with products
+        self._create_product_template(
             'product 1',
-            category=category,
-            type='goods',
-            list_price=Decimal('10'),
-            cost_price=Decimal('5'),
+            [{
+                'category': category,
+                'type': 'goods',
+                'list_price': Decimal('10'),
+                'cost_price': Decimal('5'),
+            }],
             uri='product-1',
         )
-        self._create_product(
+        self._create_product_template(
             'product 2',
-            category=category2,
-            type='goods',
-            list_price=Decimal('20'),
-            cost_price=Decimal('5'),
+            [{
+                'category': category2,
+                'type': 'goods',
+                'list_price': Decimal('20'),
+                'cost_price': Decimal('5'),
+            }],
             uri='product-2',
         )
-        self._create_product(
+        self._create_product_template(
             'product 3',
-            category=category3,
-            type='goods',
-            list_price=Decimal('30'),
-            cost_price=Decimal('5'),
+            [{
+                'category': category3,
+                'type': 'goods',
+                'list_price': Decimal('30'),
+                'cost_price': Decimal('5'),
+            }],
             uri='product-3',
         )
-        self._create_product(
+        self._create_product_template(
             'product 4',
-            category=category,
-            displayed_on_eshop=False,
-            type='goods',
-            list_price=Decimal('30'),
-            cost_price=Decimal('5'),
+            [{
+                'category': category,
+                'type': 'goods',
+                'list_price': Decimal('30'),
+                'cost_price': Decimal('5'),
+            }],
             uri='product-4',
+            displayed_on_eshop=False
         )
 
     def setUp(self):
+        """
+        Set up data used in the tests.
+        this method is called before each test execution.
+        """
         trytond.tests.test_tryton.install_module('nereid_catalog')
-        self.currency_obj = POOL.get('currency.currency')
-        self.site_obj = POOL.get('nereid.website')
-        self.product_obj = POOL.get('product.product')
-        self.company_obj = POOL.get('company.company')
-        self.nereid_user_obj = POOL.get('nereid.user')
-        self.url_map_obj = POOL.get('nereid.url_map')
-        self.language_obj = POOL.get('ir.lang')
-        self.nereid_website_obj = POOL.get('nereid.website')
+
+        self.Currency = POOL.get('currency.currency')
+        self.Site = POOL.get('nereid.website')
+        self.Product = POOL.get('product.product')
+        self.Company = POOL.get('company.company')
+        self.NereidUser = POOL.get('nereid.user')
+        self.UrlMap = POOL.get('nereid.url_map')
+        self.Language = POOL.get('ir.lang')
+        self.NereidWebsite = POOL.get('nereid.website')
+        self.Party = POOL.get('party.party')
 
         self.templates = {
-            'localhost/home.jinja':
+            'home.jinja':
                 '{{request.nereid_website.get_currencies()}}',
-            'localhost/login.jinja':
+            'login.jinja':
                 '{{ login_form.errors }} {{get_flashed_messages()}}',
-            'localhost/product-list.jinja':
+            'product-list.jinja':
                 '{% for product in products %}'
                 '|{{ product.name }}|{% endfor %}',
-            'localhost/category.jinja':
+            'category.jinja':
                 '{% for product in products %}'
                 '|{{ product.name }}|{% endfor %}',
-            'localhost/category-list.jinja':
+            'category-list.jinja':
                 '{%- for category in categories %}'
                 '|{{ category.name }}|'
                 '{%- endfor %}',
-            'localhost/search-results.jinja':
+            'search-results.jinja':
                 '{% for product in products %}'
                 '|{{ product.name }}|{% endfor %}',
-            'localhost/product.jinja': '{{ product.sale_price(product.id) }}',
-            'localhost/wishlist.jinja':
+            'product.jinja': '{{ product.sale_price(product.id) }}',
+            'wishlist.jinja':
                 '{% for product in products %}|{{ product.uri }}|{% endfor %}',
         }
 
